#version 150

#moj_import <fog.glsl>

uniform vec4 ColorModulator;
uniform float GameTime;
uniform float FogStart;
uniform float FogEnd;
uniform vec4 FogColor;
uniform vec2 ScreenSize;

in mat4 ProjInv;
in vec3 position;
in float isSky;
in float vertexDistance;

out vec4 fragColor;

#define GRIDOFFSET 0.078
#define GRIDDENSITY 10.0

void main() {
    // get player space view vector
    vec4 screenPos = gl_FragCoord;
    screenPos.xy = (screenPos.xy / ScreenSize - vec2(0.5)) * 2.0;
    screenPos.zw = vec2(1.0);
    vec3 view = normalize((ProjInv * screenPos).xyz);

    float vdn = dot(view, vec3(0.0, 1.0, 0.0));
    float vdt = dot(view, vec3(1.0, 0.0, 0.0));
    float vdb = dot(view, vec3(0.0, 0.0, 1.0));
    
    // custom fog calculation if sky because sky disc is no longer above the head
    if (isSky > 0.5) {
        float ndusq = clamp(dot(view, vec3(0.0, 1.0, 0.0)), 0.0, 1.0);
        ndusq = ndusq * ndusq;
		
		vec4 color = ColorModulator;
		if (color.r < 0.05) color.r = 0.05;
		if (color.g < 0.0155) color.g = 0.0155;
		if (color.b < 0.07525) color.b = 0.07525;
		fragColor = linear_fog(color, pow(1.0 - ndusq, 8.0), 1.25, 1.25, FogColor);
    } 
    // default shading for void plane and stars
    else {
		vec4 color = ColorModulator;
		if (color.r + color.g + color.b > 0.1) { 
			color += vec4(0.2, 0.2, -0.05, 0.0); 
			color.a *= 3.0;
			color.a += abs(sin((GameTime * 1000.0) + position.x + position.z)) * -2.0;
		}
		
        fragColor = linear_fog(color, vertexDistance, FogStart, FogEnd, FogColor);
    }
}